@@ -166,6 +166,11 @@ public:
      */
     int selectedItemsCount() const;
 
+    /**
+     * Returns the selected kfileitem if one is selected and only one
+     */
+    std::optional<KFileItem> firstSelectedItem() const;
+
     /**
      * Marks the items indicated by \p urls to get selected after the
      * directory DolphinView::url() has been loaded. Note that nothing
@@ -496,6 +501,11 @@ Q_SIGNALS:
      */
     void itemActivated(const KFileItem &item);
 
+    /**
+     * request the property dialog
+     */
+    void requestPropertyDialog();
+
     /**
      * Is emitted when clicking on a file with the middle mouse button.
      * @note: This will not be emitted for folders or file archives that will/can be opened like folders.
@@ -849,6 +859,8 @@ private Q_SLOTS:
      */
     void observeCreatedItem(const QUrl &url);
 
+    void observeCreatedDirectory(const QUrl &url);
+
     /**
      * Selects the next item after prev selection deleted/trashed
      */
@@ -948,6 +960,8 @@ private:
 
     bool tryShowNameToolTip(QHelpEvent *event);
 
+    void selectFileOnceAvailable(const QUrl &url, std::function<bool()> condition);
+
 private:
     void updatePalette();
     void showLoadingPlaceholder();
