@@ -65,6 +65,9 @@ public:
     void setSortHiddenLast(bool hiddenLast);
     bool sortHiddenLast() const;
 
+    void setDynamicViewPassed(bool dynamicViewPassed);
+    bool dynamicViewPassed() const;
+
     /**
      * Sets the additional information for the current set view-mode.
      * Note that the additional-info property is the only property where
